"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typedocPlugin = void 0;
const typedoc_1 = require("typedoc");
const typedoc_plugin_markdown_1 = require("typedoc-plugin-markdown");
const options_1 = require("../shared/options");
const render_1 = require("../shared/render");
const theme_1 = require("../shared/theme");
const sidebar_1 = require("./sidebar");
let app;
let project;
const typedocPlugin = (opts) => {
    return (ctx) => {
        const typedocOptions = (0, options_1.getTypedocOptions)(opts);
        const outputDirectory = ctx.dir.source() + '/' + typedocOptions.out;
        if (typedocOptions.cleanOutputDir) {
            (0, render_1.removeDir)(outputDirectory);
        }
        app = new typedoc_1.Application();
        (0, typedoc_plugin_markdown_1.load)(app);
        (0, options_1.addOptions)(app);
        app.renderer.render = render_1.render;
        app.renderer.defineTheme('vuepress', theme_1.VuepressTheme);
        app.bootstrap(typedocOptions);
        project = app.convert();
        if (!project) {
            return;
        }
        if (typedocOptions.watch) {
            app.convertAndWatch(async (project) => {
                app.generateDocs(project, outputDirectory);
            });
        }
        else {
            app.generateDocs(project, outputDirectory);
        }
        return {
            name: 'vuepress-plugin-typedoc',
            extendsPageOptions: (pageOptions) => {
                var _a;
                const sidebarOptions = (0, options_1.getSidebarOptions)(opts);
                if (!sidebarOptions.autoConfiguration) {
                    return;
                }
                if ((_a = pageOptions.filePath) === null || _a === void 0 ? void 0 : _a.startsWith(outputDirectory)) {
                    const theme = app.renderer.theme;
                    const navigation = theme.getNavigation(project);
                    const sidebarJson = (0, sidebar_1.getSidebarJson)(navigation, sidebarOptions, typedocOptions.out);
                    pageOptions.frontmatter = {
                        sidebar: sidebarJson,
                    };
                }
            },
        };
    };
};
exports.typedocPlugin = typedocPlugin;
